Class: Google::Cloud::Firestore::V1::DocumentDelete
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::V1::DocumentDelete
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/v1/write.rb
Overview
A Document has been deleted.
May be the result of multiple writes, including updates, the last of which deleted the Document.
Multiple DocumentDelete messages may be returned for the same logical delete, if multiple targets are affected.
Instance Attribute Summary collapse
-
#document ⇒ ::String
The resource name of the Document that was deleted.
-
#read_time ⇒ ::Google::Protobuf::Timestamp
The read timestamp at which the delete was observed.
-
#removed_target_ids ⇒ ::Array<::Integer>
A set of target IDs for targets that previously matched this entity.
Instance Attribute Details
#document ⇒ ::String
Returns The resource name of the Document that was deleted.
249 250 251 252 |
# File 'proto_docs/google/firestore/v1/write.rb', line 249 class DocumentDelete include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#read_time ⇒ ::Google::Protobuf::Timestamp
Returns The read timestamp at which the delete was observed.
Greater or equal to the commit_time of the delete.
249 250 251 252 |
# File 'proto_docs/google/firestore/v1/write.rb', line 249 class DocumentDelete include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#removed_target_ids ⇒ ::Array<::Integer>
Returns A set of target IDs for targets that previously matched this entity.
249 250 251 252 |
# File 'proto_docs/google/firestore/v1/write.rb', line 249 class DocumentDelete include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |