Class: Google::Cloud::Firestore::V1::ExplainStats

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/firestore/v1/explain_stats.rb

Overview

Pipeline explain stats.

Depending on the explain options in the original request, this can contain the optimized plan and / or execution stats.

Instance Attribute Summary collapse

Instance Attribute Details

#data::Google::Protobuf::Any

Returns The format depends on the output_format options in the request.

Currently there are two supported options: TEXT and JSON. Both supply a google.protobuf.StringValue.

Returns:

  • (::Google::Protobuf::Any)

    The format depends on the output_format options in the request.

    Currently there are two supported options: TEXT and JSON. Both supply a google.protobuf.StringValue.



34
35
36
37
# File 'proto_docs/google/firestore/v1/explain_stats.rb', line 34

class ExplainStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end