Class: Google::Cloud::Firestore::V1::Pipeline
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::V1::Pipeline
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/v1/document.rb
Overview
A Firestore query represented as an ordered list of operations / stages.
Defined Under Namespace
Classes: Stage
Instance Attribute Summary collapse
Instance Attribute Details
#stages ⇒ ::Array<::Google::Cloud::Firestore::V1::Pipeline::Stage>
Returns Required. Ordered list of stages to evaluate.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'proto_docs/google/firestore/v1/document.rb', line 273 class Pipeline include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A single operation within a pipeline. # # A stage is made up of a unique name, and a list of arguments. The exact # number of arguments & types is dependent on the stage type. # # To give an example, the stage `filter(state = "MD")` would be encoded as: # # ``` # name: "filter" # args { # function_value { # name: "eq" # args { field_reference_value: "state" } # args { string_value: "MD" } # } # } # ``` # # See public documentation for the full list. # @!attribute [rw] name # @return [::String] # Required. The name of the stage to evaluate. # # **Requires:** # # * must be in snake case (lower case with underscore separator). # @!attribute [rw] args # @return [::Array<::Google::Cloud::Firestore::V1::Value>] # Optional. Ordered list of arguments the given stage expects. # @!attribute [rw] options # @return [::Google::Protobuf::Map{::String => ::Google::Cloud::Firestore::V1::Value}] # Optional. Optional named arguments that certain functions may support. class Stage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Firestore::V1::Value] class OptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |