Class: Google::Cloud::Firestore::V1::Value
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::V1::Value
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/v1/document.rb
Overview
A message that can hold any of the supported value types.
Instance Attribute Summary collapse
-
#array_value ⇒ ::Google::Cloud::Firestore::V1::ArrayValue
An array value.
-
#boolean_value ⇒ ::Boolean
A boolean value.
-
#bytes_value ⇒ ::String
A bytes value.
-
#double_value ⇒ ::Float
A double value.
-
#field_reference_value ⇒ ::String
Value which references a field.
-
#function_value ⇒ ::Google::Cloud::Firestore::V1::Function
A value that represents an unevaluated expression.
-
#geo_point_value ⇒ ::Google::Type::LatLng
A geo point value representing a point on the surface of Earth.
-
#integer_value ⇒ ::Integer
An integer value.
-
#map_value ⇒ ::Google::Cloud::Firestore::V1::MapValue
A map value.
-
#null_value ⇒ ::Google::Protobuf::NullValue
A null value.
-
#pipeline_value ⇒ ::Google::Cloud::Firestore::V1::Pipeline
A value that represents an unevaluated pipeline.
-
#reference_value ⇒ ::String
A reference to a document.
-
#string_value ⇒ ::String
A string value.
-
#timestamp_value ⇒ ::Google::Protobuf::Timestamp
A timestamp value.
-
#variable_reference_value ⇒ ::String
Pointer to a variable defined elsewhere in a pipeline.
Instance Attribute Details
#array_value ⇒ ::Google::Cloud::Firestore::V1::ArrayValue
Returns An array value.
Cannot directly contain another array value, though can contain a map which contains another array.
Note: The following fields are mutually exclusive: array_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#boolean_value ⇒ ::Boolean
Returns A boolean value.
Note: The following fields are mutually exclusive: boolean_value, null_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bytes_value ⇒ ::String
Returns A bytes value.
Must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes are considered by queries.
Note: The following fields are mutually exclusive: bytes_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#double_value ⇒ ::Float
Returns A double value.
Note: The following fields are mutually exclusive: double_value, null_value, boolean_value, integer_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#field_reference_value ⇒ ::String
Returns Value which references a field.
This is considered relative (vs absolute) since it only refers to a field and not a field within a particular document.
Requires:
Must follow [field reference][FieldReference.field_path] limitations.
Not allowed to be used when writing documents.
Note: The following fields are mutually exclusive: field_reference_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#function_value ⇒ ::Google::Cloud::Firestore::V1::Function
Returns A value that represents an unevaluated expression.
Requires:
- Not allowed to be used when writing documents.
Note: The following fields are mutually exclusive: function_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#geo_point_value ⇒ ::Google::Type::LatLng
Returns A geo point value representing a point on the surface of Earth.
Note: The following fields are mutually exclusive: geo_point_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#integer_value ⇒ ::Integer
Returns An integer value.
Note: The following fields are mutually exclusive: integer_value, null_value, boolean_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#map_value ⇒ ::Google::Cloud::Firestore::V1::MapValue
Returns A map value.
Note: The following fields are mutually exclusive: map_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#null_value ⇒ ::Google::Protobuf::NullValue
Returns A null value.
Note: The following fields are mutually exclusive: null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pipeline_value ⇒ ::Google::Cloud::Firestore::V1::Pipeline
Returns A value that represents an unevaluated pipeline.
Requires:
- Not allowed to be used when writing documents.
Note: The following fields are mutually exclusive: pipeline_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reference_value ⇒ ::String
Returns A reference to a document. For example:
projects/{project_id}/databases/{database_id}/documents/{document_path}.
Note: The following fields are mutually exclusive: reference_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#string_value ⇒ ::String
Returns A string value.
The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes of the UTF-8 representation are considered by queries.
Note: The following fields are mutually exclusive: string_value, null_value, boolean_value, integer_value, double_value, timestamp_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#timestamp_value ⇒ ::Google::Protobuf::Timestamp
Returns A timestamp value.
Precise only to microseconds. When stored, any additional precision is rounded down.
Note: The following fields are mutually exclusive: timestamp_value, null_value, boolean_value, integer_value, double_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, variable_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variable_reference_value ⇒ ::String
Returns Pointer to a variable defined elsewhere in a pipeline.
Unlike field_reference_value which references a field within a
document, this refers to a variable, defined in a separate namespace than
the fields of a document.
Note: The following fields are mutually exclusive: variable_reference_value, null_value, boolean_value, integer_value, double_value, timestamp_value, string_value, bytes_value, reference_value, geo_point_value, array_value, map_value, field_reference_value, function_value, pipeline_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
196 197 198 199 |
# File 'proto_docs/google/firestore/v1/document.rb', line 196 class Value include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |