Class: Google::Cloud::Firestore::V1::ExecutePipelineResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::V1::ExecutePipelineResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/v1/firestore.rb
Overview
The response for [Firestore.Execute][].
Instance Attribute Summary collapse
-
#execution_time ⇒ ::Google::Protobuf::Timestamp
The time at which the results are valid.
-
#explain_stats ⇒ ::Google::Cloud::Firestore::V1::ExplainStats
Query explain stats.
-
#results ⇒ ::Array<::Google::Cloud::Firestore::V1::Document>
An ordered batch of results returned executing a pipeline.
-
#transaction ⇒ ::String
Newly created transaction identifier.
Instance Attribute Details
#execution_time ⇒ ::Google::Protobuf::Timestamp
The time at which the results are valid.
This is a (not strictly) monotonically increasing value across multiple
responses in the same stream. The API guarantees that all previously
returned results are still valid at the latest execution_time. This
allows the API consumer to treat the query if it ran at the latest
execution_time returned.
If the query returns no results, a response with execution_time and no
results will be sent, and this represents the time at which the operation
was run.
538 539 540 541 |
# File 'proto_docs/google/firestore/v1/firestore.rb', line 538 class ExecutePipelineResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#explain_stats ⇒ ::Google::Cloud::Firestore::V1::ExplainStats
Returns Query explain stats.
This is present on the last response if the request configured explain
to run in 'analyze' or 'explain' mode in the pipeline options. If the query
does not return any results, a response with explain_stats and no
results will still be sent.
538 539 540 541 |
# File 'proto_docs/google/firestore/v1/firestore.rb', line 538 class ExecutePipelineResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#results ⇒ ::Array<::Google::Cloud::Firestore::V1::Document>
Returns An ordered batch of results returned executing a pipeline.
The batch size is variable, and can even be zero for when only a partial progress message is returned.
The fields present in the returned documents are only those that were
explicitly requested in the pipeline, this includes those like
__name__ and
__update_time__. This is
explicitly a divergence from Firestore.RunQuery / Firestore.GetDocument
RPCs which always return such fields even when they are not specified in
the mask.
538 539 540 541 |
# File 'proto_docs/google/firestore/v1/firestore.rb', line 538 class ExecutePipelineResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transaction ⇒ ::String
Returns Newly created transaction identifier.
This field is only specified as part of the first response from the server,
alongside the results field when the original request specified
[ExecuteRequest.new_transaction][].
538 539 540 541 |
# File 'proto_docs/google/firestore/v1/firestore.rb', line 538 class ExecutePipelineResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |