Class: Google::Cloud::Firestore::V1::TransactionOptions::ReadWrite
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::V1::TransactionOptions::ReadWrite
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/v1/common.rb
Overview
Options for a transaction that can be used to read and write documents.
Instance Attribute Summary collapse
-
#concurrency_mode ⇒ ::Google::Cloud::Firestore::V1::TransactionOptions::ConcurrencyMode
Optional.
-
#retry_transaction ⇒ ::String
An optional transaction to retry.
Instance Attribute Details
#concurrency_mode ⇒ ::Google::Cloud::Firestore::V1::TransactionOptions::ConcurrencyMode
Returns Optional. The concurrency control mode to use for this transaction.
A database is able to use different concurrency modes for different transactions simultaneously.
3rd party auth requests are only allowed to create optimistic read-write transactions and must specify that here even if the database-level setting is already configured to optimistic.
87 88 89 90 |
# File 'proto_docs/google/firestore/v1/common.rb', line 87 class ReadWrite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |